#
# spec file for package zoxide
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'

Name:           zoxide
Version:        0.9.6
Release:        1.1
Summary:        A smarter cd command
License:        MIT
Group:          System/Console
URL:            https://github.com/ajeetdsouza/zoxide
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  cargo
BuildRequires:  rust >= 1.31

%description
zoxide is a smarter cd command, inspired by z and autojump. It remembers
which directories you use most frequently, so you can "jump" to them in
just a few keystrokes.

%prep
%autosetup -p1 -a1

%build
export RUSTFLAGS=%{rustflags}
cargo build --release %{?_smp_mflags}

%install
export RUSTFLAGS=%{rustflags}
RUSTFLAGS=%{rustflags} cargo install --path . --root=%{buildroot}%{_prefix} %{?_smp_mflags}

# install manpages
ls -la
install -Dpm 644 man/man1/%{name}*.1 -t %{buildroot}%{_mandir}/man1/

# install shell completions
install -Dpm 644 contrib/completions/%{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dpm 644 contrib/completions/_%{name} -t %{buildroot}%{_datadir}/zsh/site-functions/
install -Dpm 644 contrib/completions/%{name}.fish -t %{buildroot}/%{_datadir}/fish/vendor_completions.d/

# remove residue crate file
rm -f %{buildroot}%{_prefix}/.crates*

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*.1*
%{_datadir}/bash-completion/completions/%{name}
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Thu Sep 19 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.9.6:
  * Fish: builtin abbr doesn't work on older versions.
  * Zsh: make __zoxide_z_complete available with --no-cmd.
* Fri Sep 13 2024 pallas wept <pallaswept@proton.me>
- Update to 0.9.5:
  Added:
  * zsh: improved cd completions.
  * Lazily delete excluded directories from the database.
  * fish: detect infinite loop when using alias cd=z.
  * Installer: added flags for --bin-dir, --man-dir, --arch, and --sudo.
  * Nushell: support for v0.94.0+.
  * bash/fish/zsh: support for z -- dir style queries.
  * fish: improved Space-Tab completions.
  * ksh: added support for the Korn shell.
  Changed:
  * fzf: removed --select-1 from default options. The interactive selector will
    now open up even if there is only one match.
  * Enforce that $_ZO_DATA_DIR is an absolute path.
  Fixed:
  * zsh: Space-Tab completion repeating output multiple times when matching single
    directory
  * fish / Nushell / PowerShell: handle queries that look like args (e.g. z -x).
  * elvish: z - now works as expected.
  * fish: generated shell code avoids using aliased builtins.
  * fish: cd command is now copied directly from
    $__fish_data_dir/functions/cd.fish. This should minimize the chances of an
    infinite loop when aliasing cd=z.
  * Symlinks not getting added to the database when $_ZO_RESOLVE_SYMLINKS=0.
  * Symlinked database files getting replaced instead of the actual files.
- Use new cargo service features for package
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.9.4:
  * zsh: improved Space-Tab completions
* Tue Feb 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.9.3:
  Added:
  * Nushell: support for v0.89.0.
* Fri Aug  4 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.2:
  Added:
  * Short option -a for zoxide query --all.
  Fixed:
  * PowerShell: use global scope for variables / functions.
* Sun May  7 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.1:
  Added:
  * Fish/Zsh: aliases on __zoxide_z will now use completions.
  * Nushell: add support for v0.78.0.
  * Fish: plugin now works on older versions.
  * PowerShell: warn when PowerShell version is too old for z - and z +.
  * PowerShell: support for PWD hooks on all versions.
  Fixed:
  * Fish: not providing cd completions when there is a space in the path.
  * Bash/Fish/Zsh: providing z completions when the last argument starts with z!.
  * Bash/Fish/Zsh: attempting to cd when the last argument is z!.
* Mon Jan  9 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  Added:
  * edit subcommand to adjust the scores of entries.
  Fixed:
  * Zsh: completions clashing with zsh-autocomplete.
  * Fzf: 'invalid option' on macOS.
  * PowerShell: handle UTF-8 encoding correctly.
  * Zsh: don't hide output from chpwd hooks.
  * Nushell: upgrade minimum supported version to v0.73.0.
  * Zsh: fix extra space in interactive completions when no match is found.
  * Fzf: various improvements.
  * Nushell: Accidental redefinition of hooks when initialized twice.
  Removed:
  * remove -i subcommand: use edit instead.
* Tue Sep 27 2022 Jacob Hansen <me@jacobbaungard.com>
- Version 0.8.3
  * ADDED: Nushell: support for `z -` and PWD hooks.
  * CHANGED: Fish: change fuzzy completion prefix to `z!`.
  * CHANGED: Zsh: allow z to navigate dirstack via +n and -n.
  * CHANGES: Fzf: improved preview window.
  * FIXED: Bash: double forward slash in completions.
* Fri Jul  1 2022 Jacob Hansen <me@jacobbaungard.com>
- Version 0.8.2:
  * CHANGED: Fzf: show preview window below results.
  * FIXED: Fish: completions not working on certain systems.
  * FIXED: Bash: completions not escaping spaces correctly.
* Thu Jun 16 2022 Jacob Hansen <me@jacobbaungard.com>
- Updated description in spec file so it matches the description
  provided by the upstream project.
* Tue Jun 14 2022 Jacob Hansen <me@jacobbaungard.com>
- Ship shell completions for:
  * bash
  * zsh
  * fish
- Ship man-pages
* Fri Jun 10 2022 Jacob Hansen <me@jacobbaungard.com>
- Upstream version 0.8.1:
  * CHANGED: Manpages: moved to man/man1/*.1.
  * CHANGED: Replace --no-aliases with --no-cmd.
  * CHANGED: Elvish: upgrade minimum supported version to v0.18.0.
  * CHANGED: Nushell: upgrade minimum supported version to v0.61.0.
  * FIXED: Bash/Zsh: rename _z completion function to avoid
    conflicts with other shell plugins.
  * FIXED: Fzf: added --keep-right option by default, upgrade
    minimum supported version to v0.21.0.
  * FIXED: Bash: only enable completions on 4.4+.
  * FIXED: Fzf: bypass ls alias in preview window.
  * FIXED: Retain ownership of database file.
  * FIXED: zoxide query --interactive should not conflict with --score.
- Upstream version 0.8.0:
  * ADDED: Zsh: completions for z command.
  * CHANGED: Fzf: better default options.
  * CHANGED: Fish: interactive completions are only triggered when
    the last argument is empty.
  * FIXED: Zsh: fix errors with set -eu.
  * FIXED: Fzf: handle early selection.
  * FIXED: Fzf: handle spaces correctly in preview window.
  * FIXED: Bash: avoid initializing completions on older versions.
- Upstream version 0.7.9:
  * CHANGED: Bash/Fish: improved completions for z command.
  * FIXED: Fish: error erasing completions on older versions.
- Upstream version 0.7.6:
  * CHANGED: Nushell: upgrade minimum supported version to v0.37.0.
  * FIXED: Xonsh: error messages in zi.
  * FIXED: Xonsh: configuration environment variables not being
    handled correctly.
- Upstream version 0.7.5
  * ADDED: Bash/Elvish: completions for z command.
  * FIXED: Nushell: upgrade minimum supported version to
    v0.36.0.
  * FIXED: Elvish: unable to z into directories by path.
  * FIXED: Elvish: don't show traceback when z or zi fails.
  * FIXED: Elvish: nested shells do not initialize correctly.
- Upstream version 0.7.3:
  * ADDED: zoxide add and zoxide remove now accept multiple
    arguments.
  * FIXED: Xonsh: use shell environment instead of os.environ.
  * FIXED: Bash: remove extra semicolon when setting
    $PROMPT_COMMAND.
  * FIXED: Bash/POSIX: remove conflicting alias definitions when
    initializing.
  * FIXED: Nushell: errors on 0.33.0.
* Wed Jul 28 2021 Andreas Schneider <asn@cryptomilk.org>
- Initial package
